@@ -16,7 +16,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-    define('VERSION', '0.7.0.2');
+    define('VERSION', '0.7.1');
 
     define('DB_HOST', 'localhost');
     define('DB_NAME', 'zoph');
@@ -79,6 +79,15 @@
     // Watermark must be a GIF image, transparancy is honoured!
     // the filename is relative to the image root (IMAGE_DIR)
     define('WATERMARK', 'watermark.gif');
+    
+    // Position of the watermark: left, centre or right
+    define('WM_POSX', 'center');
+    // Position of the watermark: top, centre or bottom
+    define('WM_POSY', 'center');
+    // Transparency of the watermark overlay
+    // 0 = fully transparent (invisible) to 100 = no transparency
+    define('WM_TRANS', 50);
+
 
     // If set to 1, users can leave comments with photos
     define('ALLOW_COMMENTS', 0);
@@ -88,6 +97,10 @@
     define('CLIENT_WEB_IMPORT', 1);
     define('SERVER_WEB_IMPORT', 0);
 
+    // If set to 1, move images into their final location after uploading, 
+    // otherwise, the images are copied and you have the same image twice.
+    define('IMPORT_MOVE',1);
+
     // Maximum filesize to be uploaded, in bytes:
     // Make sure you also change "upload_max_filesize" "post_max_size"
     // and possibly "max_execution_time" and "max_input_time" in php.ini
@@ -98,7 +111,11 @@
     //define('UNZIP_CMD', 'unzip');
     define('UNTAR_CMD', 0);
     //define('UNTAR_CMD', 'tar xvf');
-
+    
+    // Enable downloading of a set of photos in a ZIP file.
+    // Warning: the downloaded photos are NOT watermarked.
+    define('DOWNLOAD', 0);
+        
     // directory to use to temporarily extract uploaded archives
     define('EXTRACT_DIR', '/tmp');
 
