@@ -22,6 +22,10 @@
     $_order = getvar("_order");
     $_dir = getvar("_dir");
 
+    if(!preg_match("/^[a-zA-Z_]*$/", $_order)) {
+        die("Illegal characters in _order");
+    }
+
     if (!$_cols) { $_cols = $DEFAULT_COLS; }
     if (!$_rows) { $_rows = $DEFAULT_ROWS; }
     if (!$_off)  { $_off = 0; }
