@@ -71,12 +71,25 @@
             <a href="person.php?_action=edit&amp;person_id=<?php echo $person->get("person_id") ?>"><?php echo translate("edit") ?></a> |
             <a href="person.php?_action=delete&amp;person_id=<?php echo $person->get("person_id") ?>"><?php echo translate("delete") ?></a> |
             <a href="person.php?_action=new"><?php echo translate("new") ?></a>
+<?php
+            if($person->get("coverphoto")) {
+?>
+                |
+                <a href="person.php?_action=update&amp;person_id=<?php echo $person->get("person_id") ?>&amp;coverphoto=NULL"><?php echo translate("unset coverphoto") ?></a>
+<?php
+            }
+?>
           </span>
 <?php
         }
 ?>
         <?php echo translate("person") ?>
      </h1>
+<?php
+    if($user->is_admin()) {
+        include("selection.inc.php");
+    }
+?>
       <div class="main">
           <span class="actionlink">
             <a href="photos.php?person_id=<?php echo $person->get("person_id") ?>"><?php echo "$photos_of " . translate("photos of") ?></a> |
@@ -87,57 +100,54 @@
             <?php echo $person->get("middle_name") ?>
             <?php echo $person->get("last_name") ?>
           </h2>
-          <table id="person">
+          <p>
 <?php
-    if ($user->get("detailed_people")) {
+    echo $person->get_coverphoto($user);
 ?>
-<?php echo create_field_html($person->get_display_array(), 3) ?>
+          </p>
+          <dl>
+<?php
+if ($user->get("detailed_people") || $user->is_admin()) {
+?>
+<?php echo create_field_html($person->get_display_array()) ?>
 <?php
         if ($person->get_email()) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("email") ?></td>
-          <td class="field"><a href="mailto:<?php echo $person->get_email() ?>"><?php echo $person->get_email() ?></a></td>
-        </tr>
+          <dt><?php echo translate("email") ?></dt>
+          <dd><a href="mailto:<?php echo $person->get_email() ?>"><?php echo $person->get_email() ?></a></dd>
 <?php
         }
         if ($person->home) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("home") ?></td>
-          <td class="field">
+          <dt><?php echo translate("home") ?></dt>
+          <dd>
           <span class="actionlink"><a href="place.php?place_id=<?php echo $person->get("home_id") ?>"><?php echo translate("view") ?></a></span>
-          <?php echo $person->home->get_address() ?></td>
-        </tr>
+          <?php echo $person->home->get_address() ?></dd>
 <?php
         }
 
         if ($person->work) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("work") ?></td>
-          <td class="field">
+          <dt"><?php echo translate("work") ?></dt>
+          <dd>
           <span class="actionlink"><a href="place.php?place_id=<?php echo $person->get("work_id") ?>"><?php echo translate("view") ?></a></span>
              <?php echo $person->work->get("title") ? $person->work->get("title") . "<br>" : "" ?>
              <?php echo $person->work->get_address() ?>
-          </td>
-        </tr>
+          </dd>
 <?php
         }
 
         if ($person->get("notes")) {
 ?>
-        <tr>
-          <td class="fieldtitle">notes</td>
-          <td colspan="2" class="field"><?php echo $person->get("notes") ?></td>
-        </tr>
+          <dt>notes</dt>
+          <dd><?php echo $person->get("notes") ?></dd>
 <?php
         }
 
     } // detailed_people
 
 ?>
-</table>
+</dl>
 <?php
 
     } // display
@@ -158,6 +168,7 @@
 require_once("edit_person.inc.php");
     }
 ?>
+<br>
 </div>
 
 <?php require_once("footer.inc.php"); ?>
