@@ -40,6 +40,11 @@
     if (empty($encoded_qs)) {
         $encoded_qs = urlencode(htmlentities($qs));
     }
+    /* if page is called via a HTTP POST, the $QUERY_STRING variable is empty
+       so we need to fill $qs differently... */
+    if (empty($qs)) {
+        $qs=$_qs;
+    }
 
     if ($photo_id) { // would be passed for edit or delete
         $photo = new photo($photo_id);
@@ -184,11 +189,12 @@
         $action = "update";
     }
     else if ($_action == "update") {
+        $actionlinks["return"]="photo.php?_action=display&amp;" . $return_qs;
         unset($actionlinks["cancel"]);
         unset($actionlinks["edit"]);
 
         $photo->set_fields($request_vars);
-        $photo->update($request_vars); // pass again for add people, cats, etc
+        $photo->update($request_vars,'',$user); // pass again for add people, cats, etc
         $action = "update";
     }
     else if ($_action == "new") {
@@ -228,12 +234,13 @@
         }
         $action="display";
     } else if ($_action == "deselect") {
+        $return=getvar("_return");
         $sel_key=array_search($photo_id, $_SESSION["selected_photo"]);
 
         if($sel_key !== false) {
             unset($_SESSION["selected_photo"][$sel_key]);
         }
-        header("Location: photo.php?" . html_entity_decode(urldecode($_qs)));
+        header("Location: " . $return . "?" . html_entity_decode(urldecode($_qs)));
     // 2005-04-10 --JCT
     //
     // lightbox and rate actions moved
@@ -261,7 +268,6 @@
     else {
         $title = translate("New Photo");
     }
-
 require_once("header.inc.php");
     // no photo was found and this isn't a new record
     if ($action != "insert" && !$found) {
@@ -297,23 +303,24 @@ require_once("header.inc.php");
 <?php
         if (ALLOW_ROTATIONS && ($user->is_admin() || $permissions->get("writable"))) {
 ?>
-          <div id="rotate">
-        <form action="<?php echo $PHP_SELF ?>" method="POST">
-<input type="hidden" name="photo_id" value="<?php echo $photo->get("photo_id") ?>">
-
-<select name="_deg">
-<option>90</option>
-<option>180</option>
-<option>270</option>
-</select>
-<input type="submit" name="_button" value="<?php echo translate("rotate", 0) ?>">
-</form>
-      </div>
+        <div id="rotate">
+            <form action="<?php echo $PHP_SELF ?>" method="POST">
+                <p>
+                    <input type="hidden" name="photo_id" value="<?php echo $photo->get("photo_id") ?>">
+                    <select name="_deg">
+                        <option>90</option>
+                        <option>180</option>
+                        <option>270</option>
+                    </select>
+                    <input type="submit" name="_button" value="<?php echo translate("rotate", 0) ?>">
+                </p>
+            </form>
+        </div>
 <?php
         }
 ?>
-                <div id="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
-                <div id="photohdr">
+        <div id="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
+        <div id="photohdr">
 <?php
         if ($up_link) {
 ?>
@@ -336,68 +343,73 @@ require_once("header.inc.php");
 <?php
         }
 ?>
-<table id="photo">
-<?php echo create_field_html($photo->get_display_array(), 2) ?>
+<dl>
+<?php echo create_field_html($photo->get_display_array()) ?>
 <?php
         if (ALLOW_RATINGS || $photo->get("rating")) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("rating") ?></td>
-          <td class="field">
-<form action="<?php echo $PHP_SELF ?>" method="POST">
-                  <?php echo $photo->get("rating") != 0 ? $photo->get("rating") . " / 10" : ""; ?>
+          <dt><?php echo translate("rating") ?></dt>
+          <dd><?php echo $photo->get("rating") != 0 ? $photo->get("rating") . " / 10" : ""; ?>
 <?php
             if (ALLOW_RATINGS) {
 ?>
-<input type="hidden" name="_action" value="rate">
-<input type="hidden" name="photo_id" value="<?php echo $photo->get("photo_id") ?>">
-<input type="submit" name="_button" value="<?php echo translate("rate", 0) ?>">
-<?php echo create_rating_pulldown($photo->get_rating($user->get("user_id"))); ?>
+<form id="ratingform" action="<?php echo $PHP_SELF ?>" method="POST">
+    <p>
+        <input type="hidden" name="_action" value="rate">
+        <input type="hidden" name="photo_id" value="<?php echo $photo->get("photo_id") ?>">
+        <?php echo create_rating_pulldown($photo->get_rating($user->get("user_id"))); ?>
+        <input type="submit" name="_button" value="<?php echo translate("rate", 0) ?>">
+    </p>
+</form>
+        </dd>
 <?php
             }
 ?>
-           </form>
-          </td>
-        </tr>
 <?php
         }
         if ($album_links = create_link_list($photo->lookup_albums($user))) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("albums") ?></td>
-          <td class="field"><?php echo $album_links ?></td>
-        </tr>
+<dt><?php echo translate("albums") ?></dt>
+<dd><?php echo $album_links ?></dd>
 <?php
         }
 
         if ($category_links = create_link_list($photo->lookup_categories())) {
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("categories") ?></td>
-          <td class="field"><?php echo $category_links ?></td>
-        </tr>
+          <dt><?php echo translate("categories") ?></dt>
+          <dd><?php echo $category_links ?></dd>
 <?php
         }
 ?>
-        <tr>
-          <td class="fieldtitle"><?php echo translate("last modified") ?></td>
-          <td class="field"><?php echo format_timestamp($photo->get("timestamp")) ?></td>
-        </tr>
-        <tr>
-          <td colspan="2" class="photodesc">
+          <dt><?php echo translate("last modified") ?></dt>
+          <dd><?php echo format_timestamp($photo->get("timestamp")) ?></dd>
 <?php
         if ($photo->get("description")) {
-            echo $photo->get("description");
+        
+            echo "<div class=\"photodesc\">" . $photo->get("description") . "</div><br>\n";
         }
 ?>
-          </td>
-        </tr>
 <?php
         if ($user->prefs->get("camera_info")) {
-            echo create_field_html($photo->get_camera_display_array(), 2);
-            echo "</table>\n";
+            echo create_field_html($photo->get_camera_display_array());
         }
+?>
+</dl><br>
+<?php
+        if ($user->prefs->get("allexif")) {
+            $allexif=$photo->exif_to_html();
 
+            if($allexif) {
+?>
+                <h2><?php echo translate("Full EXIF details",0)?></h2>
+                <span class="actionlink">
+                    <a href="#" onclick="document.getElementById('allexif').style.display='block'"><?php echo translate("display",0) ?></a> | 
+                    <a href="#" onclick="document.getElementById('allexif').style.display='none'"><?php echo translate("hide",0) ?></a>
+                </span>
+<?php
+                echo $allexif;
+            }
+        }
         $related=$photo->get_related();
 
         if ($related) {
@@ -436,6 +448,9 @@ require_once("header.inc.php");
             echo "<br>&nbsp;\n";
             }
         }
+?>
+        <br>
+<?php
     }
     else if ($action == "confirm") {
 ?>
