@@ -22,6 +22,7 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
     $good_conj = array ( "and", "or" );
 
     $good_fields= array ( "location_id", "rating", "photographer_id", "date", "time", "timestamp", "name", "path", "title", "view", "description", "width", "height", "size", "aperture", "camera_make", "camera_model", "compression", "exposure", "flash_used", "focal_length", "iso_equiv", "metering_mode" );
+    $good_text= array ( "album", "category", "person", "photographer" );
 
     $select = "distinct ph.photo_id, ph.name, ph.path, ph.width, ph.height";
 
@@ -48,12 +49,18 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
     }
 
     global $DEFAULT_ORDER;
-    $ord = $vars["_order"];
-    if (!$ord) { $ord = $DEFAULT_ORDER; }
+    if (isset($vars["_order"])) {
+        $ord = $vars["_order"];
+    } else {
+        $ord = $DEFAULT_ORDER;
+    }
 
     global $DEFAULT_DIRECTION;
-    $dir = $vars["_dir"];
-    if (!$dir) { $dir = $DEFAULT_DIRECTION; }
+    if (isset($vars["_dir"])) {
+        $dir = $vars["_dir"];
+    } else {
+        $dir = $DEFAULT_DIRECTION;
+    }
 
     $order = "ph." . $ord . " $dir";
     if ($ord == "date") { $order .= ", ph.time $dir"; }
@@ -75,19 +82,25 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
 
         //echo "key = $key<br>";
         //echo "suffix = $suffix<br>";
+        $index = "_" . $key . $suffix;
 
-        $conj = $vars["_" . $key . $suffix . "-conj"];
-        if (!$conj) { $conj = "and"; }
+        if (!empty($vars[$index . "-conj"])) {
+            $conj = $vars[$index . "-conj"];
+        } else {
+            $conj = "and";
+        }
         if (!in_array($conj, $good_conj)) 
             { die ("Illegal conjunction: " . $conj); }
 
-        $op = $vars["_" . $key . $suffix . "-op"];
-        if (!$op) { $op = "="; }
+        if (!empty($vars[$index . "-op"])) {
+            $op = $vars[$index . "-op"];
+        } else {
+            $op = "=";
+        }
         if (!in_array($op, $good_ops)) 
             { die ("Illegal operator: " . $op); }
 
-        $children=$vars["_" . $key . $suffix . "-children"];
-        if($children) {
+        if (!empty($vars[$index . "-children"])) {
             $val_no_children=split(",",$val);
             $val=$val_no_children[0];
         }
@@ -97,15 +110,31 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
             else if ($op = "!=") { $op = "is not"; }
         }
 
+        if ($key == "text") { 
+            if (strncasecmp($key, "text", 4) == 0) {
+                $key = $vars["_" . $key . $suffix];
+            }
+            if (!in_array($key, $good_text))
+                { die ("Illegal text search: " . $key); }
+              
+            $val = escape_string($val);
+            $key = escape_string($key);
+        }
+
         if ($key == "person" || $key == "photographer") {
-            // val could be "last_name", "last_name,first_name" or ",first_name"
+            $val = "%" . escape_string(strtolower($val)) . "%";
+            
+            $query = "select person_id from " . DB_PREFIX . "people where 
+                        lower(concat(first_name, \" \", last_name)) like \"$val\"";
+
+            $people = get_records_from_query("person", $query); 
 
-            list($last_name, $first_name) = explode(',', $val);
 
             $key .= "_id";
             $val = "";
+            
+            $op = "=";
 
-            $people = get_person_by_name($first_name, $last_name);
             if ($people && count($people) > 0) {
 
                 foreach ($people as $person) {
@@ -260,7 +289,10 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
                 $from["$ppl"] = "photo_people";
 
                 $op = "in";
-                if (!is_numeric($val)) { die("$key must be numeric"); }
+                // the regexp matches a list of numbers, separated by comma's.
+                // "1" matches, "1," not, "1,2" matches "1,333" matches
+                // "1, a" not, etc.
+                if (!preg_match("/^-*([0-9]+)+(,([0-9]+))*$/", $val)) { die("$key must be numeric"); }
                 $where .=
                     "(${ppl}.person_id $op (" . escape_string($val) . ")" .
                     " and ${ppl}.photo_id = ph.photo_id)";
@@ -305,25 +337,26 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
         }
 
     }
+    if(!empty($from)) {
+        $from_clause .= generate_from_clause($from);
+    }
 
-    $from_clause .= generate_from_clause($from);
-
-    if ($excluded_albums) {
+    if (!empty($excluded_albums)) {
         $where .= generate_excluded_albums_clause(
             $excluded_albums, $from_clause, $where);
     }
 
-    if ($excluded_categories) {
+    if (!empty($excluded_categories)) {
         $where .= generate_excluded_categories_clause(
             $excluded_categories, $from_clause, $where);
     }
 
-    if ($excluded_people) {
+    if (!empty($excluded_people)) {
         $where .= generate_excluded_people_clause(
             $excluded_people, $from_clause, $where);
     }
     
-    if ($where) { $where = "where $where"; }
+    if (!empty($where)) { $where = "where $where"; }
 
     $num_photos = 0;
 
@@ -334,7 +367,7 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
 
     if ($num_photos > 0) {
 
-        if ($vars["_random"] && $num_photos > 1) {
+        if (isset($vars["_random"]) && $num_photos > 1) {
             // get one random result
             mt_srand((double) microtime() * 1000000);
             $offset = mt_rand(0, $num_photos - 1);
