@@ -18,6 +18,15 @@
 
     require_once("include.inc.php");
 
+    $_view=getvar("_view");
+    if(empty($_view)) {
+        $_view=$user->prefs->get("view");
+    }
+    $_autothumb=getvar("_autothumb");
+    if(empty($_autothumb)) {
+        $_autothumb=$user->prefs->get("autothumb");
+    }
+
     if (!$user->is_admin() && !$user->get("browse_places")) {
         header("Location: " . add_sid("zoph.php"));
     }
@@ -49,13 +58,44 @@
 ?>
         <?php echo translate("places") . "\n" ?>
     </h1>
+<?php
+    if ($user->is_admin()) {
+        include("selection.inc.php");
+    }
+?>
     <div class="main">
 <?php
+    if(JAVASCRIPT) {
+?>
+        <form class="viewsettings" method="get" action="places.php">
+<?php
+            echo create_pulldown("parent_place_id", 0, get_places_select_array($user), "onChange='form.submit()'");
+?>
+            <?php echo create_form($request_vars, array ("_view", "_autothumb",
+"_button")) ?>
+            <?php echo translate("Category view", 0) . "\n" ?>
+            <?php echo create_view_pulldown("_view", $_view, "onChange='form.submit()'") ?>
+            <?php echo translate("Automatic thumbnail", 0) . "\n" ?>
+            <?php echo create_autothumb_pulldown("_autothumb", $_autothumb, "onChange='form.submit()'") ?>
+
+        </form>
+     <br>
+<?php
+    }
+
     if ($user->is_admin()) {
 ?>
         <span class="actionlink">
             <a href="place.php?_action=edit&amp;place_id=<?php echo $place->get("place_id") ?>"><?php echo translate("edit") ?></a> | 
             <a href="place.php?_action=delete&amp;place_id=<?php echo $place->get("place_id") ?>"><?php echo translate("delete") ?></a>
+<?php
+            if($place->get("coverphoto")) {
+?>
+                |
+                <a href="place.php?_action=update&amp;place_id=<?php echo $place->get("place_id") ?>&amp;coverphoto=NULL"><?php echo translate("unset coverphoto") ?></a>
+<?php
+            }
+?>
         </span>
         
         <h2>
@@ -69,14 +109,14 @@
     }
 ?>
         </h2>
-      <form id="quicknav">
-<?php
-        echo create_pulldown("parent_place_id", 0, get_places_select_array($user), "onChange='form.submit()'");
-?>
-      </form>
+        <p>
 <?php
     }
-    if ($user->get("detailed_places")) {
+    echo $place->get_coverphoto($user);
+?>
+        </p>
+<?php
+    if ($user->get("detailed_places") || $user->is_admin()) {
         echo $place->to_html();
         if ($place->get("notes")) {
             echo $place->get("notes");
@@ -136,15 +176,49 @@
     }
     if ($children) {
 ?>
-        <ul>
+        <ul class="<?php echo $_view ?>">
 <?php
-        foreach($children as $a) {
+        if($_view!="tree") {
+            foreach($children as $a) {
+                $photo_count=$a->get_photo_count($user);
+                $total_photo_count=$a->get_total_photo_count($user);
+                if($photo_count==$total_photo_count) {
+                    $count=" <span class=\"photocount\">(" . $photo_count . ")</span>";
+                } else {
+                    $count=" <span class=\"photocount\">(" . $photo_count ."/" . $total_photo_count . ")</span>";
+                }
 ?>
-            <li><a href="places.php?parent_place_id=<?php echo $a->get("place_id") ?>"><?php echo $a->get("title") ?></a></li>
+                <li>
+                    <a href="places.php?parent_place_id=<?php echo $a->get("place_id") ?>">
+<?php
+                    if ($_view=="thumbs") {
+?>
+                        <p>
+                            <?php echo $a->get_coverphoto($user,$_autothumb); ?>
+                            &nbsp;
+                        </p>
+                        <div>
+<?php
+                    }
+                    echo $a->get("title");
+                    echo $count;
+                    if ($_view=="thumbs") {
+?>
+                        </div>
+<?php
+                    }
+?>
+                </a>
+            </li>
+
 <?php
         }
+    } else {
+        echo $place->get_html_tree();
+    }
 ?>
         </ul>
+        <br>
 <?php
     }
 ?>
