@@ -243,7 +243,20 @@ function create_autothumb_pulldown($name, $value, $extraopt=null) {
         "highest" => translate("Highest ranked",0), 
         "random" => translate("Random",0)), $extraopt);
 }
-
+function get_sort_array() {
+    return array(
+        "name" => translate("Name",0),
+        "sortname" => translate("Sort Name",0),
+        "oldest" => translate("Oldest photo",0), 
+        "newest" => translate("Newest photo",0), 
+        "first" => translate("Changed least recently",0), 
+        "last" => translate("Changed most recently",0), 
+        "lowest" => translate("Lowest ranked",0), 
+        "highest" => translate("Highest ranked",0), 
+        "average" => translate("Average ranking",0), 
+        "random" => translate("Random",0)
+    );
+}
 /*
  * Remove any params without values and operator params without corresponding
  * fields (e.g. _album_id-op when there is no _album_id).  This can be called
@@ -650,4 +663,86 @@ function get_autothumb_order($autothumb) {
     return $order;
 }
 
+function create_zipfile($photos, $maxsize, $filename, $filenum, $user) {
+    if(class_exists(ZipArchive)) {
+        $zip=new ZipArchive();
+        $tempfile="/tmp/zoph_" . $user->get("user_id") . "_" . $filename ."_" . $filenum . ".zip";
+        @unlink($tempfile);
+        if ($zip->open($tempfile, ZIPARCHIVE::CREATE)!==TRUE) {
+            die("cannot open $tempfile\n");
+        }
+        $count=sizeof($photos);
+        foreach($photos as $key => $photo) {
+            if($data=@file_get_contents($photo->get_file_path())) {
+                $size=strlen($data);
+                $zipsize=$zipsize+$size;
+                if($zipsize>=$maxsize) {
+                    break;
+                }
+                $currentfile=$key;
+                $zip->addFromString($photo->get("name"),$data);
+            
+            } else {
+                echo sprintf(translate("Could not read %s."), $photo->get_file_path()) . "<br>\n";
+            }
+        }
+        $zip->close() or die ("Zipfile creation failed");
+        return $currentfile;
+    } else {
+        echo translate("You need to have ZIP support in PHP to download zip files");
+        return FALSE;
+    }
+}
+
+function get_human($bytes) {
+    // transforms a size in bytes into a human readable format using 
+    // Ki Mi Gi, etc. prefixes
+    // Give me a call if your database grows bigger than 1024 Yobbibytes. :-)
+    if($bytes==0) {
+        // prevents div by 0
+        return "0B";
+    } else {
+        $prefixes=array("", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi", "Yi");
+        $length=floor(log($bytes,2)/10);
+        return round($bytes/pow(2,10*($length)),1) . $prefixes[floor($length)] . "B";
+    }
+}
+
+function watermark_image($orig, $watermark, $positionX = "center", $positionY = "center", $transparency = 50) {
+
+    $wm=imagecreatefromgif($watermark);
+    
+    $width_orig=ImageSX($orig);
+    $height_orig=ImageSY($orig);
+
+    $width_wm=ImageSX($wm);
+    $height_wm=ImageSY($wm);
+
+    switch ($positionX) {
+    case "left":
+        $destX = 5;
+        break;
+    case "right":
+        $destX = $width_orig - $width_wm - 5;
+        break;
+    default:
+        $destX = ($width_orig / 2) - ($width_wm / 2);
+        break;
+    }
+
+    switch ($positionY) {
+    case "top":
+        $destY = 5;
+        break;
+    case "bottom":
+        $destY = $height_orig - $height_wm - 5;
+        break;
+    default:
+        $destY = ($height_orig / 2) - ($height_wm / 2);
+        break;
+    }
+    ImageCopyMerge($orig, $wm, $destX, $destY, 0, 0, $width_wm, $height_wm, $transparency);
+    imagedestroy($wm);
+    return $orig;
+}
 ?>
