@@ -59,7 +59,7 @@ class zoph_tree_table extends zoph_table {
             $sql .= " order by $order";
         }
 
-        if ($this->DEBUG) { echo "$sql<br>\n"; }
+        if (DEBUG) { echo "$sql<br>\n"; }
 
         $this->children = get_records_from_query(get_class($this), $sql);
         return $this->children;
@@ -118,6 +118,67 @@ class zoph_tree_table extends zoph_table {
         return implode(",", $id_array);
     }
 
+    function get_html_tree() {
+        $this->lookup();
+        $children=$this->get_children();
+
+        $html="<li>\n";
+        if($children) {
+            $html.="<span onclick=\"branch(this)\">+&nbsp;</span>";
+        } else {
+            $html.="<span>&nbsp;&nbsp;</span>";
+        }
+        $html.=$this->get_link();
+        if($children) {
+            $html.= "<ul>";
+        }
+        foreach($children as $child) {
+            $html .= $child->get_html_tree();
+        }
+        if($children) {
+            $html .= "</ul>";
+        }
+        $html.="</li>\n";
+        return $html;
+    }
+
+
+
+
+    function get_xml_tree($xml, $search) {
+        $rootname=$this->xml_rootname();
+        $nodename=$this->xml_nodename();
+        $idname=$this->primary_keys[0];
+
+        $newchild=$xml->createElement($nodename);
+
+        $title=$this->get_name();
+
+        $titleshort=strtolower(substr($title, 0, strlen($search)));
+        if($titleshort == strtolower($search)) {
+            $key=$this->get($idname);
+
+            $newchildkey=$xml->createElement("key");
+            $newchildkey->appendChild($xml->createTextNode($key));
+            $newchildtitle=$xml->createElement("title");
+            $newchildtitle->appendChild($xml->createTextNode($title));
+
+            $newchild->appendChild($newchildkey);
+            $newchild->appendChild($newchildtitle);
+       }
+        if($this->get_children()) {
+            $childset=$xml->createElement($rootname);
+            foreach($this->get_children() as $child) {
+                $newnode=$child->get_xml_tree($xml, $search);
+                if (isset($newnode)) {
+                    $childset->appendChild($newnode);
+                }
+            }
+            $newchild->appendChild($childset);
+
+        }
+        return $newchild;
+    }
 }
 
 function get_root($class) {
